check_fonts: Check font status

View source: R/fonts.R

check_fontsR Documentation

Check font status

Description

Reports which math fonts are loaded and available for rendering. Shows the MicroTeX version, loaded math fonts, and whether bundled font files are present.

Usage

check_fonts()

Value

Invisibly returns the character vector of available font names.

Examples

check_fonts()

gridmicrotex documentation built on May 16, 2026, 5:06 p.m.