dot-get_glyph_font: Get or create a glyphFont object for a font file

.get_glyph_fontR Documentation

Get or create a glyphFont object for a font file

Description

Caches grDevices::glyphFont() objects keyed by file path so that repeated calls for the same font file reuse the same object.

Usage

.get_glyph_font(font_file)

Arguments

font_file

Absolute path to the OTF/TTF font file.

Value

A glyphFont object.


gridmicrotex documentation built on May 16, 2026, 5:06 p.m.