gridmicrotex-package: gridmicrotex: Native 'LaTeX' Math Rendering for Grid Graphics

gridmicrotex-packageR Documentation

gridmicrotex: Native 'LaTeX' Math Rendering for Grid Graphics

Description

Renders 'LaTeX' math equations as native R grid graphics objects (grobs) using the 'MicroTeX' 'C++' library as the layout engine. Produces resolution-independent vector output that works on any R graphics device, with no external 'LaTeX' installation required.

Author(s)

Maintainer: Alim Dayim ad938@cam.ac.uk (ORCID)

Other contributors:

  • Nano Michael (Author of included 'MicroTeX' library) [copyright holder]

  • Bundled math font authors (See inst/COPYRIGHTS for the full list of authors of the bundled math fonts.) [copyright holder]

See Also

Useful links:


gridmicrotex documentation built on May 16, 2026, 5:06 p.m.