Returns the math fonts that can be passed to math_font.
Font pairing
For a consistent look, pair each math font with a matching
fontfamily in gp:
| Math font | Style | Suggested text font |
Lete Sans Math ("lete", default) | Sans-serif | "sans" |
STIX Two Math ("stix") | Serif | "serif" |
Additional math fonts can be loaded with load_math_font.