Skip to contents

Returns the names of all math fonts currently loaded by MicroTeX. These names can be passed to the math_font parameter of latex_grob and grid.latex.

Usage

available_math_fonts()

Value

A character vector of math font names.

Font pairing

The bundled math fonts have different styles. For a consistent look, pair them with a matching fontfamily in gp:

Math fontStyleSuggested text font
Lete Sans Math ("lete", default)Sans-serif"sans"
STIX Two Math ("stix")Serif"serif"

Additional math fonts can be loaded with load_font.

Examples

available_math_fonts()
#> [1] "Lete Sans Math" "STIX Two Math"