Skip to contents

Reports which math fonts are loaded and available for rendering. Shows the MicroTeX version, loaded math fonts, and whether bundled font files are present.

Usage

check_fonts()

Value

Invisibly returns the character vector of available font names.

Examples

check_fonts()
#> MicroTeX version: 1.0.0
#> Loaded math fonts (4):
#>   - LatinModernMath-Regular
#>   - Lete Sans Math
#>   - STIX Two Math
#>   - TeXGyreDejaVuMath-Regular
#> Bundled font files:
#>   - Latin Modern Math: found
#>   - STIX Two Math: found
#>   - Lete Sans Math: found
#>   - TeX Gyre DejaVu Math: found