| check_fonts | R Documentation |
Reports which math fonts are loaded and available for rendering. Shows the MicroTeX version, loaded math fonts, and whether bundled font files are present.
check_fonts()
Invisibly returns the character vector of available font names.
check_fonts()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.