| gridmicrotex-package | R Documentation |
Renders 'LaTeX' math equations as native R grid graphics objects (grobs) using the 'MicroTeX' 'C++' library as the layout engine. Produces resolution-independent vector output that works on any R graphics device, with no external 'LaTeX' installation required.
Maintainer: Alim Dayim ad938@cam.ac.uk (ORCID)
Other contributors:
Nano Michael (Author of included 'MicroTeX' library) [copyright holder]
Bundled math font authors (See inst/COPYRIGHTS for the full list of authors of the bundled math fonts.) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.